@@ -1,4 +1,7 @@
 package XML::Toolkit::MetaDescription::Attribute;
+{
+  $XML::Toolkit::MetaDescription::Attribute::VERSION = '0.15';
+}
 use Moose;
 use XML::Toolkit::MetaDescription;
 use namespace::autoclean;
@@ -6,8 +9,7 @@ use namespace::autoclean;
 extends 'MooseX::MetaDescription::Meta::Attribute';
 with 'XML::Toolkit::MetaDescription::Trait';
 
-
-__PACKAGE__->meta->make_immutable;
+__PACKAGE__->meta->make_immutable( inline_constructor => 0 );
 1;
 __END__
 
@@ -17,7 +19,7 @@ XML::Toolkit::MetaDescription::Attribute - A class to ...
 
 =head1 VERSION
 
-This documentation refers to version 0.01.
+version 0.15
 
 =head1 SYNOPSIS
 
